<?php

/**
 * Provide a admin area view for the plugin.
 * This file is used to markup the admin-facing aspects of the plugin.
 * 
 * @since      1.0.0
 * @package    SmokeDrop
 * @subpackage SmokeDrop/admin/partials
 */

/**
 * Prevent direct access to this file.
 */
if ( !defined( 'ABSPATH' ) ) {
	exit;
}
?>

<div class="smokedrop-section">
    <div class="smokedrop-container">
        <div class="smokedrop-heading">
            <h1><?php esc_html_e( 'SmokeDrop Integration', 'smokedrop' ); ?></h1>
        </div>

        <div class="smokedrop-card">
            <div class="smokedrop-card-integrate">
                <div class="smokedrop-integrate-content">
                    <p><?php esc_html_e( 'Instructions for connecting a WooCommerce store to a Smoke Drop account', 'smokedrop' ); ?></p>
                    <ol>
                        <li>
                            <?php esc_html_e( 'In your WooCommerce account, generate a new API key', 'smokedrop' ); ?>
                            <ol>
                                <li><strong><?php esc_html_e( 'Please note that the API Key must be generated by a user with Admin permissions', 'smokedrop' ); ?></strong></li>
                                <li><a href="https://woocommerce.com/document/woocommerce-rest-api/#section-2"><?php esc_html_e( 'How to generate a new WooCommerce API Key', 'smokedrop' ); ?></a></li>
                                <li><?php esc_html_e( 'Smoke Drop requires read/write permissions for the API key', 'smokedrop' ); ?></li>
                                <li><?php esc_html_e( 'We recommend updating to the latest version of WooCommerce prior to generating your API key', 'smokedrop' ); ?></li>
                            </ol>
                        </li>
                        <li><?php esc_html_e( 'Log in to your Smoke Drop account', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'From the homepage, go to Account', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'Select General from the sidebar', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'Select WooCommerce', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'Enter your store name', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'Enter your API key and API secret from WooCommerce', 'smokedrop' ); ?></li>
                        <li>
                            <?php esc_html_e( 'Enter your store domain', 'smokedrop' ); ?>
                            <ol>
                                <li>
                                    <?php
                                        printf(
                                            // translators: %s is a link to the website prefix (e.g., https://www.).
                                            esc_html__( 'In most cases, you will need to include %s and a forward slash at the end of your domain.', 'smokedrop' ), 
                                            '<a href="#" rel="noreferrer noopener" target="_blank">https://www.</a>'
                                        );
                                    ?>
                                </li>
                                <li>
                                    <?php
                                        printf(
                                            // translators: %s is an example store URL (e.g., https://www.examplestore.com/).
                                            esc_html__( 'Example – %s', 'smokedrop' ), 
                                            '<a href="#" rel="noreferrer noopener" target="_blank">https://www.examplestore.com/</a>'
                                        ); 
                                    ?>
                                </li>
                            </ol>
                        </li>
                        <li><?php esc_html_e( 'Select Save', 'smokedrop' ); ?></li>
                        <li><?php esc_html_e( 'You’ve successfully connected your WooCommerce store to the app', 'smokedrop' ); ?></li>
                    </ol>
                </div>
            </div>

            <div class="smokedrop-card-updater">
                <h2><?php esc_html_e( 'Check for update', 'smokedrop' ); ?></h2>
                <p><?php esc_html_e( 'SmokeDrop is a Dropship Marketplace, this plugin helps you to import & dropship products in your WooCommerce store.', 'smokedrop' ); ?></p>
                <p><?php esc_html_e( 'Click the button below to check for new version update.', 'smokedrop' ); ?></p>
                <div class="smokedrop-update-button">
                    <button id="smokedrop-check-update" class="button smokedrop-button-primary"><?php esc_html_e( 'Check for Updates', 'smokedrop' ); ?></button>
                    <span class="spinner"></span>
                </div>
                <span class="smokedrop-update-message"></span>
            </div>
        </div>
    </div>
</div>
